From: Antoine Coeur <co...@gmx.fr>

Fix various typos in comments and documentation.

Cc: Michael D Kinney <michael.d.kin...@intel.com>
Cc: Liming Gao <liming....@intel.com>
Signed-off-by: Antoine Coeur <co...@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <phi...@redhat.com>
Reviewed-by: Michael D Kinney <michael.d.kin...@intel.com>
Signed-off-by: Philippe Mathieu-Daude <phi...@redhat.com>
---
 MdePkg/Include/IndustryStandard/Acpi10.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi20.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi30.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi40.h      |  2 +-
 MdePkg/Include/IndustryStandard/Acpi50.h      |  6 +--
 MdePkg/Include/IndustryStandard/Acpi51.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi60.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi61.h      |  4 +-
 MdePkg/Include/IndustryStandard/Acpi62.h      |  8 ++--
 MdePkg/Include/IndustryStandard/Atapi.h       | 40 +++++++++----------
 MdePkg/Include/IndustryStandard/ElTorito.h    |  4 +-
 MdePkg/Include/IndustryStandard/Emmc.h        |  2 +-
 .../IndustryStandard/IpmiNetFnBridge.h        |  4 +-
 MdePkg/Include/IndustryStandard/Nvme.h        | 10 ++---
 MdePkg/Include/IndustryStandard/Pci22.h       | 20 +++++-----
 MdePkg/Include/IndustryStandard/PeImage.h     |  2 +-
 MdePkg/Include/IndustryStandard/Scsi.h        |  2 +-
 MdePkg/Include/IndustryStandard/SmBus.h       |  2 +-
 MdePkg/Include/IndustryStandard/Tpm12.h       |  2 +-
 19 files changed, 64 insertions(+), 64 deletions(-)

diff --git a/MdePkg/Include/IndustryStandard/Acpi10.h 
b/MdePkg/Include/IndustryStandard/Acpi10.h
index a38d2be61cc3..fa06eefbb6e6 100644
--- a/MdePkg/Include/IndustryStandard/Acpi10.h
+++ b/MdePkg/Include/IndustryStandard/Acpi10.h
@@ -37,7 +37,7 @@ typedef struct {
 #pragma pack()
 
 //
-// Define for Desriptor
+// Define for Descriptor
 //
 #define ACPI_SMALL_ITEM_FLAG                   0x00
 #define ACPI_LARGE_ITEM_FLAG                   0x01
@@ -109,7 +109,7 @@ typedef struct {
 #pragma pack(1)
 
 ///
-/// The commond definition of QWORD, DWORD, and WORD
+/// The common definition of QWORD, DWORD, and WORD
 /// Address Space Descriptors.
 ///
 typedef PACKED struct {
diff --git a/MdePkg/Include/IndustryStandard/Acpi20.h 
b/MdePkg/Include/IndustryStandard/Acpi20.h
index 8a0adbbb6a97..b63d494705a2 100644
--- a/MdePkg/Include/IndustryStandard/Acpi20.h
+++ b/MdePkg/Include/IndustryStandard/Acpi20.h
@@ -11,7 +11,7 @@
 #include <IndustryStandard/Acpi10.h>
 
 //
-// Define for Desriptor
+// Define for Descriptor
 //
 #define ACPI_LARGE_GENERIC_REGISTER_DESCRIPTOR_NAME          0x02
 
@@ -505,7 +505,7 @@ typedef struct {
 #define EFI_ACPI_2_0_SYSTEM_LOCALITY_INFORMATION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'L', 'I', 'T')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_2_0_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi30.h 
b/MdePkg/Include/IndustryStandard/Acpi30.h
index 0fc947e745f4..6a7fc39c256e 100644
--- a/MdePkg/Include/IndustryStandard/Acpi30.h
+++ b/MdePkg/Include/IndustryStandard/Acpi30.h
@@ -11,7 +11,7 @@
 #include <IndustryStandard/Acpi20.h>
 
 //
-// Define for Desriptor
+// Define for Descriptor
 //
 #define ACPI_LARGE_EXTENDED_ADDRESS_SPACE_DESCRIPTOR_NAME    0x0B
 
@@ -684,7 +684,7 @@ typedef struct {
 #define 
EFI_ACPI_3_0_PCI_EXPRESS_MEMORY_MAPPED_CONFIGURATION_SPACE_BASE_ADDRESS_DESCRIPTION_TABLE_SIGNATURE
  SIGNATURE_32('M', 'C', 'F', 'G')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_3_0_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi40.h 
b/MdePkg/Include/IndustryStandard/Acpi40.h
index 53ec90c04243..c03ba7a6290b 100644
--- a/MdePkg/Include/IndustryStandard/Acpi40.h
+++ b/MdePkg/Include/IndustryStandard/Acpi40.h
@@ -1264,7 +1264,7 @@ typedef struct {
 #define EFI_ACPI_4_0_MANAGEMENT_CONTROLLER_HOST_INTERFACE_TABLE_SIGNATURE  
SIGNATURE_32('M', 'C', 'H', 'I')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_4_0_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi50.h 
b/MdePkg/Include/IndustryStandard/Acpi50.h
index 067ab68c3428..46dcdb950741 100644
--- a/MdePkg/Include/IndustryStandard/Acpi50.h
+++ b/MdePkg/Include/IndustryStandard/Acpi50.h
@@ -12,7 +12,7 @@
 #include <IndustryStandard/Acpi40.h>
 
 //
-// Define for Desriptor
+// Define for Descriptor
 //
 #define ACPI_SMALL_FIXED_DMA_DESCRIPTOR_NAME                         0x0A
 #define ACPI_LARGE_GPIO_CONNECTION_DESCRIPTOR_NAME                   0x0C
@@ -1201,7 +1201,7 @@ typedef struct {
   ///
   UINT64                                          ExitBootServicesEntry;
   ///
-  /// Timer value logged at the point just prior towhen the OS loader gaining
+  /// Timer value logged at the point just prior to when the OS loader gaining
   /// control back from calls the ExitBootServices function for UEFI 
compatible firmware.
   /// For non-UEFI compatible boots, this field must be zero.
   ///
@@ -2063,7 +2063,7 @@ typedef struct {
 #define EFI_ACPI_5_0_SOFTWARE_LICENSING_TABLE_SIGNATURE  SIGNATURE_32('S', 
'L', 'I', 'C')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_5_0_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi51.h 
b/MdePkg/Include/IndustryStandard/Acpi51.h
index e80b93f49a6a..0132f25de8ce 100644
--- a/MdePkg/Include/IndustryStandard/Acpi51.h
+++ b/MdePkg/Include/IndustryStandard/Acpi51.h
@@ -1154,7 +1154,7 @@ typedef struct {
   ///
   UINT64                                          ExitBootServicesEntry;
   ///
-  /// Timer value logged at the point just prior towhen the OS loader gaining
+  /// Timer value logged at the point just prior to when the OS loader gaining
   /// control back from calls the ExitBootServices function for UEFI 
compatible firmware.
   /// For non-UEFI compatible boots, this field must be zero.
   ///
@@ -2084,7 +2084,7 @@ typedef struct {
 #define EFI_ACPI_5_1_SOFTWARE_LICENSING_TABLE_SIGNATURE  SIGNATURE_32('S', 
'L', 'I', 'C')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_5_1_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi60.h 
b/MdePkg/Include/IndustryStandard/Acpi60.h
index 521d8a5b2ebd..94a30a81b369 100644
--- a/MdePkg/Include/IndustryStandard/Acpi60.h
+++ b/MdePkg/Include/IndustryStandard/Acpi60.h
@@ -1169,7 +1169,7 @@ typedef struct {
   ///
   UINT64                                          ExitBootServicesEntry;
   ///
-  /// Timer value logged at the point just prior towhen the OS loader gaining
+  /// Timer value logged at the point just prior to when the OS loader gaining
   /// control back from calls the ExitBootServices function for UEFI 
compatible firmware.
   /// For non-UEFI compatible boots, this field must be zero.
   ///
@@ -2327,7 +2327,7 @@ typedef struct {
 #define EFI_ACPI_6_0_SOFTWARE_LICENSING_TABLE_SIGNATURE  SIGNATURE_32('S', 
'L', 'I', 'C')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_6_0_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi61.h 
b/MdePkg/Include/IndustryStandard/Acpi61.h
index 6fac6506ccfb..985c8273ce61 100644
--- a/MdePkg/Include/IndustryStandard/Acpi61.h
+++ b/MdePkg/Include/IndustryStandard/Acpi61.h
@@ -1169,7 +1169,7 @@ typedef struct {
   ///
   UINT64                                          ExitBootServicesEntry;
   ///
-  /// Timer value logged at the point just prior towhen the OS loader gaining
+  /// Timer value logged at the point just prior to when the OS loader gaining
   /// control back from calls the ExitBootServices function for UEFI 
compatible firmware.
   /// For non-UEFI compatible boots, this field must be zero.
   ///
@@ -2359,7 +2359,7 @@ typedef struct {
 #define EFI_ACPI_6_1_SOFTWARE_LICENSING_TABLE_SIGNATURE  SIGNATURE_32('S', 
'L', 'I', 'C')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_6_1_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Acpi62.h 
b/MdePkg/Include/IndustryStandard/Acpi62.h
index e60d1dfce6ce..5a5e9b811247 100644
--- a/MdePkg/Include/IndustryStandard/Acpi62.h
+++ b/MdePkg/Include/IndustryStandard/Acpi62.h
@@ -1281,7 +1281,7 @@ typedef struct {
   ///
   UINT64                                          ExitBootServicesEntry;
   ///
-  /// Timer value logged at the point just prior towhen the OS loader gaining
+  /// Timer value logged at the point just prior to when the OS loader gaining
   /// control back from calls the ExitBootServices function for UEFI 
compatible firmware.
   /// For non-UEFI compatible boots, this field must be zero.
   ///
@@ -1650,13 +1650,13 @@ typedef struct {
 #define EFI_ACPI_6_2_SECURE_DEVICES_TABLE_REVISION      0x01
 
 ///
-/// Secure Devcice types
+/// Secure Device types
 ///
 #define EFI_ACPI_6_2_SDEV_TYPE_PCIE_ENDPOINT_DEVICE     0x01
 #define EFI_ACPI_6_2_SDEV_TYPE_ACPI_NAMESPACE_DEVICE    0x00
 
 ///
-/// Secure Devcice flags
+/// Secure Device flags
 ///
 #define EFI_ACPI_6_2_SDEV_FLAG_ALLOW_HANDOFF            BIT0
 
@@ -2890,7 +2890,7 @@ typedef struct {
 #define EFI_ACPI_6_2_SOFTWARE_LICENSING_TABLE_SIGNATURE  SIGNATURE_32('S', 
'L', 'I', 'C')
 
 ///
-/// "SPCR" Serial Port Concole Redirection Table
+/// "SPCR" Serial Port Console Redirection Table
 ///
 #define EFI_ACPI_6_2_SERIAL_PORT_CONSOLE_REDIRECTION_TABLE_SIGNATURE  
SIGNATURE_32('S', 'P', 'C', 'R')
 
diff --git a/MdePkg/Include/IndustryStandard/Atapi.h 
b/MdePkg/Include/IndustryStandard/Atapi.h
index 43d0b58ae6ec..d9abe7f28fad 100644
--- a/MdePkg/Include/IndustryStandard/Atapi.h
+++ b/MdePkg/Include/IndustryStandard/Atapi.h
@@ -484,33 +484,33 @@ typedef union {
 //
 // ATA Packet Command Code
 //
-#define ATA_CMD_FORMAT_UNIT                             0x04   ///< defined in 
ATAPI Removable Rewritable Media Devcies
+#define ATA_CMD_FORMAT_UNIT                             0x04   ///< defined in 
ATAPI Removable Rewritable Media Devices
 #define ATA_CMD_SOFT_RESET                              0x08   ///< defined 
from ATA-3
 #define ATA_CMD_PACKET                                  0xA0   ///< defined 
from ATA-3
 #define ATA_CMD_IDENTIFY_DEVICE                         0xA1   ///< defined 
from ATA-3
 #define ATA_CMD_SERVICE                                 0xA2   ///< defined 
from ATA-3
 #define ATA_CMD_TEST_UNIT_READY                         0x00   ///< defined 
from ATA-1
 #define ATA_CMD_REQUEST_SENSE                           0x03   ///< defined 
from ATA-4
-#define ATA_CMD_INQUIRY                                 0x12   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_READ_FORMAT_CAPACITY                    0x23   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_READ_CAPACITY                           0x25   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_READ_10                                 0x28   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_WRITE_10                                0x2A   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_ATAPI_SEEK                              0x2B   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_WRITE_AND_VERIFY                        0x2E   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_VERIFY                                  0x2F   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_READ_12                                 0xA8   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_WRITE_12                                0xAA   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_START_STOP_UNIT                         0x1B   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_PREVENT_ALLOW_MEDIA_REMOVAL             0x1E   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-#define ATA_CMD_MODE_SELECT                             0x55   ///< defined in 
ATAPI Removable Rewritable Media Devcies
+#define ATA_CMD_INQUIRY                                 0x12   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_READ_FORMAT_CAPACITY                    0x23   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_READ_CAPACITY                           0x25   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_READ_10                                 0x28   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_WRITE_10                                0x2A   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_ATAPI_SEEK                              0x2B   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_WRITE_AND_VERIFY                        0x2E   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_VERIFY                                  0x2F   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_READ_12                                 0xA8   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_WRITE_12                                0xAA   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_START_STOP_UNIT                         0x1B   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_PREVENT_ALLOW_MEDIA_REMOVAL             0x1E   ///< defined in 
ATAPI Removable Rewritable Media Devices
+#define ATA_CMD_MODE_SELECT                             0x55   ///< defined in 
ATAPI Removable Rewritable Media Devices
 
-#define ATA_CMD_MODE_SENSE                              0x5A   ///< defined in 
ATAPI Removable Rewritable Media Devcies
-    #define ATA_PAGE_CODE_READ_WRITE_ERROR                  0x01   ///< 
defined in ATAPI Removable Rewritable Media Devcies
-    #define ATA_PAGE_CODE_CACHING_PAGE                      0x08   ///< 
defined in ATAPI Removable Rewritable Media Devcies
-    #define ATA_PAGE_CODE_REMOVABLE_BLOCK_CAPABILITIES      0x1B   ///< 
defined in ATAPI Removable Rewritable Media Devcies
-    #define ATA_PAGE_CODE_TIMER_PROTECT_PAGE                0x1C   ///< 
defined in ATAPI Removable Rewritable Media Devcies
-    #define ATA_PAGE_CODE_RETURN_ALL_PAGES                  0x3F   ///< 
defined in ATAPI Removable Rewritable Media Devcies
+#define ATA_CMD_MODE_SENSE                              0x5A   ///< defined in 
ATAPI Removable Rewritable Media Devices
+    #define ATA_PAGE_CODE_READ_WRITE_ERROR                  0x01   ///< 
defined in ATAPI Removable Rewritable Media Devices
+    #define ATA_PAGE_CODE_CACHING_PAGE                      0x08   ///< 
defined in ATAPI Removable Rewritable Media Devices
+    #define ATA_PAGE_CODE_REMOVABLE_BLOCK_CAPABILITIES      0x1B   ///< 
defined in ATAPI Removable Rewritable Media Devices
+    #define ATA_PAGE_CODE_TIMER_PROTECT_PAGE                0x1C   ///< 
defined in ATAPI Removable Rewritable Media Devices
+    #define ATA_PAGE_CODE_RETURN_ALL_PAGES                  0x3F   ///< 
defined in ATAPI Removable Rewritable Media Devices
 
 #define ATA_CMD_GET_CONFIGURATION                       0x46   ///< defined in 
ATAPI Multimedia Devices
    #define ATA_GCCD_RT_FIELD_VALUE_ALL                      0x00   ///< 
defined in ATAPI Multimedia Devices
diff --git a/MdePkg/Include/IndustryStandard/ElTorito.h 
b/MdePkg/Include/IndustryStandard/ElTorito.h
index 31d02bcf1339..94b55d842f3c 100644
--- a/MdePkg/Include/IndustryStandard/ElTorito.h
+++ b/MdePkg/Include/IndustryStandard/ElTorito.h
@@ -1,6 +1,6 @@
 /** @file
   ElTorito Partitions Format Definition.
-  This file includes some defintions from
+  This file includes some definitions from
   1. "El Torito" Bootable CD-ROM Format Specification, Version 1.0.
   2. Volume and File Structure of CDROM for Information Interchange,
      Standard ECMA-119. (IS0 9660)
@@ -75,7 +75,7 @@ typedef union {
   } BootRecordVolume;
 
   ///
-  /// Primary Volumn Descriptor, defined in ISO 9660.
+  /// Primary Volume Descriptor, defined in ISO 9660.
   ///
   struct {
     UINT8   Type;
diff --git a/MdePkg/Include/IndustryStandard/Emmc.h 
b/MdePkg/Include/IndustryStandard/Emmc.h
index 2055c4ca18d8..5cfc95800813 100644
--- a/MdePkg/Include/IndustryStandard/Emmc.h
+++ b/MdePkg/Include/IndustryStandard/Emmc.h
@@ -224,7 +224,7 @@ typedef struct {
   UINT8   MinPerfW8B52M;                          // Minimum Write Performance 
for 8bit at 52MHz [210]
   UINT8   Reserved17;                             // Reserved [211]
   UINT8   SecCount[4];                            // Sector Count [215:212]
-  UINT8   SleepNotificationTime;                  // Sleep Notification Timout 
[216]
+  UINT8   SleepNotificationTime;                  // Sleep Notification 
Timeout [216]
   UINT8   SATimeout;                              // Sleep/awake timeout [217]
   UINT8   ProductionStateAwarenessTimeout;        // Production state 
awareness timeout [218]
   UINT8   SCVccq;                                 // Sleep current (VCCQ) [219]
diff --git a/MdePkg/Include/IndustryStandard/IpmiNetFnBridge.h 
b/MdePkg/Include/IndustryStandard/IpmiNetFnBridge.h
index 79af969a20c6..3c2084048481 100644
--- a/MdePkg/Include/IndustryStandard/IpmiNetFnBridge.h
+++ b/MdePkg/Include/IndustryStandard/IpmiNetFnBridge.h
@@ -127,12 +127,12 @@
 //
 
 //
-//  Definitions for Prepare for Discoveery command
+//  Definitions for Prepare for Discovery command
 //
 #define IPMI_BRIDGE_PREPARE_FOR_DISCOVERY  0x10
 
 //
-//  Constants and Structure definitions for "Prepare for Discoveery" command 
to follow here
+//  Constants and Structure definitions for "Prepare for Discovery" command to 
follow here
 //
 
 //
diff --git a/MdePkg/Include/IndustryStandard/Nvme.h 
b/MdePkg/Include/IndustryStandard/Nvme.h
index 9468a73d7066..9b19a2074b0d 100644
--- a/MdePkg/Include/IndustryStandard/Nvme.h
+++ b/MdePkg/Include/IndustryStandard/Nvme.h
@@ -309,11 +309,11 @@ typedef struct {
   UINT32 Exlat;             /* Exit Latency */
   UINT8  Rrt:5;             /* Relative Read Throughput */
   UINT8  Rsvd3:3;           /* Reserved as of Nvm Express 1.1 Spec */
-  UINT8  Rrl:5;             /* Relative Read Leatency */
+  UINT8  Rrl:5;             /* Relative Read Latency */
   UINT8  Rsvd4:3;           /* Reserved as of Nvm Express 1.1 Spec */
   UINT8  Rwt:5;             /* Relative Write Throughput */
   UINT8  Rsvd5:3;           /* Reserved as of Nvm Express 1.1 Spec */
-  UINT8  Rwl:5;             /* Relative Write Leatency */
+  UINT8  Rwl:5;             /* Relative Write Latency */
   UINT8  Rsvd6:3;           /* Reserved as of Nvm Express 1.1 Spec */
   UINT8  Rsvd7[16];         /* Reserved as of Nvm Express 1.1 Spec */
 } NVME_PSDESCRIPTOR;
@@ -329,7 +329,7 @@ typedef struct {
   UINT16 Ssvid;               /* PCI sub-system vendor ID */
   UINT8  Sn[20];              /* Product serial number */
 
-  UINT8  Mn[40];              /* Proeduct model number */
+  UINT8  Mn[40];              /* Product model number */
   UINT8  Fr[8];               /* Firmware Revision */
   UINT8  Rab;                 /* Recommended Arbitration Burst */
   UINT8  Ieee_oui[3];         /* Organization Unique Identifier */
@@ -657,7 +657,7 @@ typedef union {
 //
 typedef struct {
   //
-  // CDW 0, Common to all comnmands
+  // CDW 0, Common to all commands
   //
   UINT8  Opc;               // Opcode
   UINT8  Fuse:2;            // Fused Operation
@@ -869,7 +869,7 @@ typedef struct {
   //
   UINT8  AvailableSpareThreshold;
   //
-  // Contains a vendor specific estimate of the percentage of NVM subsystem 
life used based on the actual usage and the manufacturer?s prediction of NVM 
life. A value of 100 indicates that the estimated endurance of the NVM in the 
NVM subsystem has been consumed, but may not indicate an NVM subsystem failure. 
The value is allowed to exceed 100. Percentages greater than 254 shall be 
represented as 255. This value shall be updated once per power-on hour (when 
the controller is not in a sleep state).
+  // Contains a vendor specific estimate of the percentage of NVM subsystem 
life used based on the actual usage and the manufacturer's prediction of NVM 
life. A value of 100 indicates that the estimated endurance of the NVM in the 
NVM subsystem has been consumed, but may not indicate an NVM subsystem failure. 
The value is allowed to exceed 100. Percentages greater than 254 shall be 
represented as 255. This value shall be updated once per power-on hour (when 
the controller is not in a sleep state).
   //
   UINT8  PercentageUsed;
   UINT8  Reserved1[26];
diff --git a/MdePkg/Include/IndustryStandard/PeImage.h 
b/MdePkg/Include/IndustryStandard/PeImage.h
index 720bb084ac42..a3d9bbed757b 100644
--- a/MdePkg/Include/IndustryStandard/PeImage.h
+++ b/MdePkg/Include/IndustryStandard/PeImage.h
@@ -92,7 +92,7 @@ typedef struct {
 //
 #define EFI_IMAGE_FILE_RELOCS_STRIPPED      BIT0     ///< 0x0001  Relocation 
info stripped from file.
 #define EFI_IMAGE_FILE_EXECUTABLE_IMAGE     BIT1     ///< 0x0002  File is 
executable  (i.e. no unresolved externel references).
-#define EFI_IMAGE_FILE_LINE_NUMS_STRIPPED   BIT2     ///< 0x0004  Line nunbers 
stripped from file.
+#define EFI_IMAGE_FILE_LINE_NUMS_STRIPPED   BIT2     ///< 0x0004  Line numbers 
stripped from file.
 #define EFI_IMAGE_FILE_LOCAL_SYMS_STRIPPED  BIT3     ///< 0x0008  Local 
symbols stripped from file.
 #define EFI_IMAGE_FILE_BYTES_REVERSED_LO    BIT7     ///< 0x0080  Bytes of 
machine word are reversed.
 #define EFI_IMAGE_FILE_32BIT_MACHINE        BIT8     ///< 0x0100  32 bit word 
machine.
diff --git a/MdePkg/Include/IndustryStandard/Scsi.h 
b/MdePkg/Include/IndustryStandard/Scsi.h
index d03886417f86..3e966520a185 100644
--- a/MdePkg/Include/IndustryStandard/Scsi.h
+++ b/MdePkg/Include/IndustryStandard/Scsi.h
@@ -154,7 +154,7 @@
 #define EFI_SCSI_OP_SEND_VOL_TAG      0xb6
 
 //
-// Additional commands for Communition Devices
+// Additional commands for Communication Devices
 //
 #define EFI_SCSI_OP_GET_MESSAGE6    0x08
 #define EFI_SCSI_OP_GET_MESSAGE10   0x28
diff --git a/MdePkg/Include/IndustryStandard/SmBus.h 
b/MdePkg/Include/IndustryStandard/SmBus.h
index f5d6e5ef9b7d..024a7ba67a06 100644
--- a/MdePkg/Include/IndustryStandard/SmBus.h
+++ b/MdePkg/Include/IndustryStandard/SmBus.h
@@ -1,5 +1,5 @@
 /** @file
-  This file declares the SMBus definitions defined in SmBus Specifciation V2.0
+  This file declares the SMBus definitions defined in SmBus Specification V2.0
   and defined in PI1.0 specification volume 5.
 
   Copyright (c) 2007 - 2018, Intel Corporation. All rights reserved.<BR>
diff --git a/MdePkg/Include/IndustryStandard/Tpm12.h 
b/MdePkg/Include/IndustryStandard/Tpm12.h
index 2537c192b3f8..e85a567e83be 100644
--- a/MdePkg/Include/IndustryStandard/Tpm12.h
+++ b/MdePkg/Include/IndustryStandard/Tpm12.h
@@ -597,7 +597,7 @@ typedef struct tdTPM_CHANGEAUTH_VALIDATE {
 
 ///
 /// Part 2, section 5.12: TPM_MIGRATIONKEYAUTH
-///   decalared after section 10 to catch declaration of TPM_PUBKEY
+///   declared after section 10 to catch declaration of TPM_PUBKEY
 ///
 /// Part 2 section 10.1: TPM_KEY_PARMS
 ///   [size_is(parmSize)] BYTE* parms;
diff --git a/MdePkg/Include/IndustryStandard/Pci22.h 
b/MdePkg/Include/IndustryStandard/Pci22.h
index 5fd054c4cfbe..81a854f69577 100644
--- a/MdePkg/Include/IndustryStandard/Pci22.h
+++ b/MdePkg/Include/IndustryStandard/Pci22.h
@@ -5,7 +5,7 @@
     PCI Local Bus Specification, 2.2
     PCI-to-PCI Bridge Architecture Specification, Revision 1.2
     PC Card Standard, 8.0
-    PCI Power Management Interface Specifiction, Revision 1.2
+    PCI Power Management Interface Specification, Revision 1.2
 
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
   Copyright (c) 2014 - 2015, Hewlett-Packard Development Company, L.P.<BR>
@@ -111,11 +111,11 @@ typedef union {
 } PCI_TYPE_GENERIC;
 
 ///
-/// CardBus Conroller Configuration Space,
+/// CardBus Controller Configuration Space,
 /// Section 4.5.1, PC Card Standard. 8.0
 ///
 typedef struct {
-  UINT32  CardBusSocketReg;     ///< Cardus Socket/ExCA Base
+  UINT32  CardBusSocketReg;     ///< Cardbus Socket/ExCA Base
   UINT8   Cap_Ptr;
   UINT8   Reserved;
   UINT16  SecondaryStatus;      ///< Secondary Status
@@ -222,7 +222,7 @@ typedef struct {
 #define     PCI_IF_8259_PIC               0x00
 #define     PCI_IF_ISA_PIC                0x01
 #define     PCI_IF_EISA_PIC               0x02
-#define     PCI_IF_APIC_CONTROLLER        0x10  ///< I/O APIC interrupt 
controller , 32 bye none-prefectable memory.
+#define     PCI_IF_APIC_CONTROLLER        0x10  ///< I/O APIC interrupt 
controller , 32 byte none-prefetchable memory.
 #define     PCI_IF_APIC_CONTROLLER2       0x20
 #define   PCI_SUBCLASS_DMA              0x01
 #define     PCI_IF_8237_DMA               0x00
@@ -509,7 +509,7 @@ typedef struct {
 #define IS_PCI_MULTI_FUNC(_p)         ((_p)->Hdr.HeaderType & 
HEADER_TYPE_MULTI_FUNCTION)
 
 ///
-/// Rom Base Address in Bridge, defined in PCI-to-PCI Bridge Architecure 
Specification,
+/// Rom Base Address in Bridge, defined in PCI-to-PCI Bridge Architecture 
Specification,
 ///
 #define PCI_BRIDGE_ROMBAR             0x38
 
@@ -642,7 +642,7 @@ typedef struct {
 
 ///
 /// PMC - Power Management Capabilities
 /// Section 3.2.3, PCI Power Management Interface Specifiction, Revision 1.2
 ///
 typedef union {
   struct {
@@ -662,7 +662,7 @@ typedef union {
 
 ///
 /// PMCSR - Power Management Control/Status
 /// Section 3.2.4, PCI Power Management Interface Specifiction, Revision 1.2
 ///
 typedef union {
   struct {
@@ -685,7 +685,7 @@ typedef union {
 
 ///
 /// PMCSR_BSE - PMCSR PCI-to-PCI Bridge Support Extensions
 /// Section 3.2.5, PCI Power Management Interface Specifiction, Revision 1.2
 ///
 typedef union {
   struct {
@@ -698,7 +698,7 @@ typedef union {
 
 ///
 /// Power Management Register Block Definition
 /// Section 3.2, PCI Power Management Interface Specifiction, Revision 1.2
 ///
 typedef struct {
   EFI_PCI_CAPABILITY_HDR  Hdr;
@@ -732,7 +732,7 @@ typedef struct {
 
 ///
 /// Slot Numbering Capabilities Register
-/// Section 3.2.6, PCI-to-PCI Bridge Architeture Specification, Revision 1.2
+/// Section 3.2.6, PCI-to-PCI Bridge Architecture Specification, Revision 1.2
 ///
 typedef struct {
   EFI_PCI_CAPABILITY_HDR  Hdr;
@@ -642,7 +642,7 @@ typedef struct {
 ///
 /// PMC - Power Management Capabilities
-/// Section 3.2.3, PCI Power Management Interface Specifiction, Revision 1.2
+/// Section 3.2.3, PCI Power Management Interface Specification, Revision 1.2
 ///
 typedef union {
@@ -662,7 +662,7 @@ typedef union {
 ///
 /// PMCSR - Power Management Control/Status
-/// Section 3.2.4, PCI Power Management Interface Specifiction, Revision 1.2
+/// Section 3.2.4, PCI Power Management Interface Specification, Revision 1.2
 ///
 typedef union {
@@ -685,7 +685,7 @@ typedef union {
 ///
 /// PMCSR_BSE - PMCSR PCI-to-PCI Bridge Support Extensions
-/// Section 3.2.5, PCI Power Management Interface Specifiction, Revision 1.2
+/// Section 3.2.5, PCI Power Management Interface Specification, Revision 1.2
 ///
 typedef union {
@@ -698,7 +698,7 @@ typedef union {
 ///
 /// Power Management Register Block Definition
-/// Section 3.2, PCI Power Management Interface Specifiction, Revision 1.2
+/// Section 3.2, PCI Power Management Interface Specification, Revision 1.2
 ///
 typedef struct {
-- 
2.21.0


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#52757): https://edk2.groups.io/g/devel/message/52757
Mute This Topic: https://groups.io/mt/69395725/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-

Reply via email to